@@ -253,14 +253,13 @@ class DynamoController(object):
         if order_type == self.ORDER_DESC:
             params["ScanIndexForward"] = False
 
-        params["columns_to_return"] = columns_to_return
         
         # pulling data from DB
-        data, count, next = self._execute_operation(type=self.TYPE_FILTER, primary_keys=params)
+        data, count, next = self._execute_operation(type=self.TYPE_FILTER, primary_keys=params, columns_to_return=columns_to_return)
         # pulling data until next=None or len(data) >= limit
         while next and len(data) < limit:
             params["ExclusiveStartKey"] = next
-            _data, _count, _next = self._execute_operation(type=self.TYPE_FILTER, primary_keys=params)
+            _data, _count, _next = self._execute_operation(type=self.TYPE_FILTER, primary_keys=params, columns_to_return=columns_to_return)
             data = data + _data
             count = count + _count
             next = _next
